==> img0ch-2.1.10.zip: img0ch/_template/default/note_form.cs <==
<html>
<head>
<title>img0ch - GAvbg̉摜etH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="Robot" content="NOINDEX,NOFOLLOW">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/fastserialize.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//-->
</script>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">

<table border="1" align="center" cellspacing="7" cellpadding="3" width="" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">

<tr><td align="center">
<img src="data:image/<?cs var:html_escape(type) ?>;base64,<?cs var:html_escape(Image) ?>" alt="e摜" />
</td></tr>

<tr><td>
<form class="comment" id="notePostForm" method="POST"
  action="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
<input type="hidden" name="post" value="1">
<input type="hidden" name="noteID" value="<?cs var:html_escape(DraftId) ?>">
<input type="submit" value="e" name="submit">
eXbhF<select name="key">
<?cs each:item = Threads ?>
<option value="<?cs var:html_escape(item.key) ?>"><?cs var:item.subject ?>(<?cs var:html_escape(item.res) ?>)</option>
<?cs /each ?>
</select><br>
OF<input type="text" name="FROM" size="19">
E-mailF<input type="text" name="mail" size="19"><br>
<textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
ҏWpXF<input type="password" name="editpass"><br>
<?cs if:Uploadable ?>폜pXF<input type="password" name="pass"><?cs /if ?>
</form>
</td>
</tr>

<?cs var:Banner ?><tr><td><?cs var:Banner ?></td></tr><?cs /if ?>

</table>

</body>
</html>

==> img0ch-3.0.0.zip: img0ch/_template/default/note_form.cs <==
<html>
<head>
<title>img0ch - GAvbg̉摜etH[</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="Robot" content="NOINDEX,NOFOLLOW">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//-->
</script>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">

<table border="1" align="center" cellspacing="7" cellpadding="3" width="" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">

<tr><td align="center">
<img src="data:image/<?cs var:html_escape(type) ?>;base64,<?cs var:html_escape(Image) ?>" alt="e摜" />
</td></tr>

<tr><td>
<form class="comment" id="notePostForm" method="POST"
  action="<?cs var:html_escape(CGIURI) ?>/img0ch-note.cgi">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
<input type="hidden" name="post" value="1">
<input type="hidden" name="noteID" value="<?cs var:html_escape(DraftId) ?>">
<input type="submit" value="e" name="submit">
eXbhF<select name="key">
<?cs each:item = Threads ?>
<option value="<?cs var:html_escape(item.key) ?>"><?cs var:item.subject ?>(<?cs var:html_escape(item.res) ?>)</option>
<?cs /each ?>
</select><br>
OF<input type="text" name="FROM" size="19">
E-mailF<input type="text" name="mail" size="19"><br>
<textarea rows="5" cols="64" wrap="off" name="MESSAGE"></textarea><br>
ҏWpXF<input type="password" name="editpass"><br>
<?cs if:Uploadable ?>폜pXF<input type="password" name="pass"><?cs /if ?>
</form>
</td>
</tr>

<?cs if:Banner ?><tr><td><?cs var:Banner ?></td></tr><?cs /if ?>

</table>

</body>
</html>
